//--------------------------------------------------------------------------------------------------
// MacsBug.r
// Copyright  1991-96 by Apple Computer, Inc. All rights reserved. 
//
//	Resource File for the MacsBug Sample Program. 
//--------------------------------------------------------------------------------------------------

/*
	Change History:
		----- R11 -----
		06/26/96	mdr		Install release marker.  Scope many globals.  Change TRUE/FALSE/NULL.
		06/01/96	gjc		[1327013] Signature and BNDL information should be SS02 - It was using 
							the default values, which conflict with "Nothing". SS02 is not taken by 
							any of the MacApp examples.
		----- R10 -----
		03/19/96	srf		Correct #ifndefs that have trailing whitespace or comments
		12/29/95	srf		removed #if SystemSevenOrLater. We require system 7 or later!
		12/29/95	srf		All alerts and dialogs have been resized and had contents moved to
							comply with "Macintosh Human Interface Guidelines" - chapter 6 and
							"Inside Macintosh - Macintosh ToolBox Essentials" - chapter 6.
		12/13/95	TWB		Move HelpStrings.r to includes. 
		10/24/95	gjc		Added default 'aete' resource
		 9/27/95	mdr		Added MW_Rez test for CW7 IDE support.
		----- 3.3b1 -----
		 5/15/95	srf		CFM-68K support. 
		 3/21/95	TWB		Don't use $$Shell from Rainbow. 
		 3/16/95	TWB		Use macros from MacAppVersion.h. 
		10/14/94	TWB		Use qNoCode. 
		 7/18/94	TWB		Remove version number from signature. 
		 7/13/94	TWB		Update version to 3.1.1. 
*/

//--------------------------------------------------------------------------------------------------
// INCLUDE FILES 
//--------------------------------------------------------------------------------------------------

// Standard Includes 

#ifndef __TYPES_R__
#include "Types.r"
#endif

#ifndef __SYSTYPES_R__
#include "SysTypes.r"
#endif

#ifndef __AEUSERTERMTYPES__
#include "AEUserTermTypes.r"
#endif

#ifndef __AEREGISTRY.R__
#include "AERegistry.r"
#endif

#ifndef __APPLEEVENTS_R__
#include "AppleEvents.r"
#endif

#ifndef __BalloonTypes__
#include "BalloonTypes.r"
#endif

#ifndef __MACAPPVERSION__
#include "MacAppVersion.h"
#endif

#ifndef __MacAppTypes__
#include "MacAppTypes.r"
#endif

#ifndef __ViewTypes__
#include "ViewTypes.r"
#endif

// Application Includes

#ifndef __MACSBUG_R_H__
#include "MacsBug.r.h"
#endif

//--------------------------------------------------------------------------------------------------
// CONSTANTS 
//--------------------------------------------------------------------------------------------------

// Finder Information
// ------------------

#if !defined(THINK_Rez) && !defined(MW_Rez)
#define kApplicationName	$$Shell("XAppName")
#else
#define kApplicationName	TARGET_APPLICATION_NAME
#endif // !THINK_Rez

//--------------------------------------------------------------------------------------------------
// Resources
//--------------------------------------------------------------------------------------------------

#ifndef THINK_Rez
#if qDebug | qPerform
include "Debug.rsrc" not 'ckid';
#endif

include "Dialog.rsrc" not 'ckid';
include "MacApp.rsrc" not 'ckid';

// Includes for Building Blocks

include "Printing.rsrc" not 'ckid';

// Include Code Resources

#ifndef MW_Rez
#if !qNoCode
include $$Shell("ObjApp")$$Shell("XAppName") 'CODE';
#if qModelCFM
include $$Shell("ObjApp")$$Shell("XAppName") 'cfrg';
include $$Shell("ObjApp")$$Shell("XAppName") 'rseg';
#endif
#endif
#endif
#endif //!THINK_Rez

//--------------------------------------------------------------------------------------------------
// RESOURCES FOR MENUS 
//--------------------------------------------------------------------------------------------------

//--------------------------------------------------------------------------------------------------
// Menu Bars 
//--------------------------------------------------------------------------------------------------

resource 'MBAR' (kMBarDisplayed,
#if qNames
kApplicationName,
#endif
	purgeable) {
	{ mApple; mFile }
};

//--------------------------------------------------------------------------------------------------
// Menus 
//--------------------------------------------------------------------------------------------------

include "Defaults.rsrc" 'CMNU' (mApple);	// Grab the default Apple menus
//include "Defaults.rsrc" 'CMNU' (mFile);		// Grab the default File menus
//include "Defaults.rsrc" 'CMNU' (mEdit);		// Grab the default Edit menu

resource 'CMNU' (mFile,
#if qNames
"mFile",
#endif
purgeable) {
	mFile,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"File",
	{
	"Quit",				noIcon, "Q",	noMark, plain, cQuit
	}
};


resource 'CMNU' (mBuzzwords,
#if qNames
"Buzzwords",
#endif
purgeable
) {
	mBuzzwords,
	textMenuProc,
	EnablingManagedByMacApp,
	enabled,
	"Buzzwords",
	 {	/* array: 13 elements */
		"Page Setup Change",	noIcon,	noKey,	noMark, plain, cChangePrinterStyle;
		"Typing",				noIcon,	noKey,	noMark,	plain, cTyping;
		"Tracker Command",		noIcon,	noKey,	noMark, plain, cTrackerCommand;
	}
};

//--------------------------------------------------------------------------------------------------
// About Box
//--------------------------------------------------------------------------------------------------

resource 'DITL' (phAboutApp,
#if qNames
"phAboutApp",
#endif
	purgeable) {
	 {	/* array DITLarray: 3 elements */
		/* [1] */
		{167, 288, 187, 348},
		Button {
			enabled,
			"OK"
		};
		/* [2] */
		{10, 75, 154, 348},
		StaticText {
			disabled,
			"This hack demonstrates scripting with MacsBug."
			"\n"
			WRITTEN_WITH_MACAPP
		};
		/* [3] */
		{10, 20, 42, 52},
		Icon {
			disabled,
			noteIcon
		}
	}
};

include "Defaults.rsrc"  'ALRT' (phAboutApp);		// Grab the default about box
///////include "Defaults.rsrc"	'aete' (0);					// Grab the default AppleEvent terminology
include "Defaults.rsrc"  'STR#' (kDefaultCredits);	// Grab the default credits


//--------------------------------------------------------------------------------------------------
// MultiFinder information
//--------------------------------------------------------------------------------------------------

/* Additional size deltas to be added to partition size */

#if qNames
#define kNamesSizeDelta 75
#else
#define kNamesSizeDelta 0
#endif

#if qDebug
#define kDebugSizeDelta 0
#else
#define kDebugSizeDelta 0
#endif

#if qModelFarCode
#define kModelFarSizeDelta 0
#else
#define kModelFarSizeDelta 0
#endif

resource 'SIZE' (-1) {
	saveScreen,
	acceptSuspendResumeEvents,
	enableOptionSwitch,
	canBackground,
	doesActivateOnFGSwitch,
	backgroundAndForeground,
	dontGetFrontClicks,
	ignoreAppDiedEvents,
	is32BitCompatible,
	isHighLevelEventAware,
	localAndRemoteHLEvents,
	notStationeryAware,				
	reserved,
	reserved,
	reserved,
	reserved,
	
	/* Suggested partition size */
	(1000 + kNamesSizeDelta + kDebugSizeDelta + kModelFarSizeDelta) * 1024,
	
	/* Minimum partition size */
	(800 + kNamesSizeDelta + kDebugSizeDelta + kModelFarSizeDelta) * 1024
};

//--------------------------------------------------------------------------------------------------
// Icons
//--------------------------------------------------------------------------------------------------

include "Defaults.rsrc"  'ICN#' (kApplicationID);	// MacApp Family large black & white	
include "Defaults.rsrc"  'ICN#' (kDocumentID);		// MacApp Document large black & white
include "Defaults.rsrc"  'ICN#' (kStationeryID);	// MacApp Stationery large black & white	
include "Defaults.rsrc"  'ics#' (kApplicationID);	// MacApp Family small black & white	
include "Defaults.rsrc"  'ics#' (kDocumentID);		// MacApp Document small black & white
include "Defaults.rsrc"  'ics#' (kStationeryID);	// MacApp Stationery small black & white
include "Defaults.rsrc"  'ics4' (kApplicationID);	// MacApp Family small 4 bit
include "Defaults.rsrc"  'ics4' (kDocumentID);		// MacApp Document small 4 bit
include "Defaults.rsrc"  'ics4' (kStationeryID);	// MacApp Stationery small 4 bit
include "Defaults.rsrc"  'ics8' (kApplicationID);	// MacApp Family small 4 bit
include "Defaults.rsrc"  'ics8' (kDocumentID);		// MacApp Document small 4 bit
include "Defaults.rsrc"  'ics8' (kStationeryID);	// MacApp Stationery small 4 bit
include "Defaults.rsrc"  'icl4' (kApplicationID);	// MacApp Family large 4 bit
include "Defaults.rsrc"  'icl4' (kDocumentID);		// MacApp Document large 4 bit
include "Defaults.rsrc"  'icl4' (kStationeryID);	// MacApp Stationery large 4 bit
include "Defaults.rsrc"  'icl8' (kApplicationID);	// MacApp Family large 8 bit
include "Defaults.rsrc"  'icl8' (kDocumentID);		// MacApp Document large 8 bit
include "Defaults.rsrc"  'icl8' (kStationeryID);	// MacApp Stationery large 8 bit

//--------------------------------------------------------------------------------------------------
// Memory usage information for MacsBug
//--------------------------------------------------------------------------------------------------

// See UMemory.h
// -------------

resource 'seg!' (kMacsBugSeg,
#if qNames
kApplicationName,
#endif
	purgeable) {
	{
		"ARes";
		"GNonRes";
		"GClose";
		"GFile";
		"GOpen";
		"GSelCommand";
		"GDoCommand";
		"BBNonRes";
		"BBOpen";
		"GNonRes2";
		"GPrint";
		"GReadResource";
		"foo";
	}
};

// Additional Resident Segments
// ----------------------------

resource 'res!' (kMacsBugRes,
#if qNames
	kApplicationName,
#endif
	purgeable) {
	{	
		"ARes";
		"MacsBugRes1";
		"MacsBugRes2";
	};
};

// Code fragment resource for PowerPC native apps
// ----------------------------------------------
#if qPowerPC
#include "CodeFragmentTypes.r"

resource 'cfrg' (0, "Configuration Info") {
	{
		kPowerPC,
		kFullLib,
		kNoVersionNum,
		kNoVersionNum,
		0,
		0,
		kIsApp,
		kOnDiskFlat,
		kZeroOffset,
		kWholeFork,
		"MacsBug"
	}
};
#endif

//--------------------------------------------------------------------------------------------------
// Icons, Bundles and FRefsOh my! (don't forget the Signature)
//--------------------------------------------------------------------------------------------------

type kSignature as 'STR ';
resource kSignature (0,
#if qNames
"Signature",
#endif
	purgeable) {
	"MacsBug Apple Computer, Inc. 1988-95"
};

resource 'FREF' (kApplicationID,
#if qNames
"MacsBug Application",
#endif
	purgeable) {
	'APPL',
	0,
	""
};

resource 'FREF' (kDocumentID,
#if qNames
"MacsBug Document",
#endif
	purgeable) {
	kFileType,
	1,
	""
};

resource 'FREF' (kStationeryID,
#if qNames
"MacsBug Stationery",
#endif
	purgeable) {
	kStationery,
	2,
	""
};

resource 'BNDL' (kBundleID,
#if qNames
"MacsBug",
#endif
	purgeable) {
	kSignature,
	0,
	{ /* array TypeArray: 2 elements */
		/* [1] */
		'ICN#',
		{ /* array IDArray: 3 elements */
			0, kApplicationID,
			1, kDocumentID,
			2, kStationeryID
		},
		/* [2] */
		'FREF',
		{ /* array IDArray: 3 elements */
			0, kApplicationID,
			1, kDocumentID,
			2, kStationeryID
		}
	}
};

//--------------------------------------------------------------------------------------------------
//  Version resources
//--------------------------------------------------------------------------------------------------

// The revision of this particular file

RESOURCE 'vers' (1,
#if qNames
"File Version",
#endif
	purgeable) {
	0x01,
	0x01,
	development,
	0x01,
	verUs,
	"1.1d1",
	"MacsBug 1.1d1, Apple Computer, Inc. 1988-95"
};

include "Defaults.rsrc"  'vers' (2);		// Overall package

//--------------------------------------------------------------------------------------------------
// Scripting
//--------------------------------------------------------------------------------------------------

resource 'aedt' (1000, 
#if qNames
	"MacsBug Events",
#endif
	purgeable) {
	{	/* array: 1 elements */
		/* [1] */
		kAEMacsBug, kAEMacsBugHeapZones, cHeapZones,
		kAEMacsBug, kAEMacsBugHeapCheck, cHeapCheck,
		kAEMacsBug, kAEMacsBugHeapTotal, cHeapTotal,
		kAEMacsBug, kAEMacsBugHeapDisplay, cHeapDisplay
	}
};

resource kAETerminologyExtension (0, 
#if qNames
	"English Terminology",
#endif
	purgeable) {
	0x1,
	0x0,
	english,
	roman,
	{	/* array Suites: 4 elements */

//========================================================================================
// Required Suite
//========================================================================================

		/* [1] */
		"Required Suite",
		"Terms that every application should support",
		kAERequiredSuite,
		1,
		1,
//----------------------------------------------------------------------------------------
// Events
//----------------------------------------------------------------------------------------
		{	/* array Events: 0 elements */
		},
//----------------------------------------------------------------------------------------
// Classes
//----------------------------------------------------------------------------------------
		{	/* array Classes: 0 elements */
		},
//----------------------------------------------------------------------------------------
// ComparisonOps
//----------------------------------------------------------------------------------------
		{	/* array ComparisonOps: 0 elements */
		},
//----------------------------------------------------------------------------------------
// Enumerations
//----------------------------------------------------------------------------------------
		{	/* array Enumerations: 0 elements */
		},

//========================================================================================
// Standard Suite
//========================================================================================

		/* [2] */
		"Standard Suite",
		"Common terms for most applications",
		'CoRe',
		1,
		1,
//----------------------------------------------------------------------------------------
// Events
//----------------------------------------------------------------------------------------
		{	/* array Events: 14 elements */
			/* [1] */
		"close", "Close an object", kAECoreSuite, kAEClose, noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the object to close",
			directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 2 elements */
				/* [1] */
			"saving", keyAESaveOptions, enumSaveOptions,
				"specifies whether changes should be saved before closing",
				optional, singleItem, enumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
				/* [2] */
			"saving in", keyAEFile, typeAlias,
				"the file in which to save the object",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			},
			/* [2] */
		"count", "Return the number of elements of a particular class within an object",
			kAECoreSuite, kAECountElements,
			typeLongInteger,
			"the number of elements",
			replyRequired, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the object whose elements are to be counted",
			directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
			{	/* array OtherParams: 1 elements */
				/* [1] */
			"each", keyAEObjectClass, cType,
				"the class of the elements to be counted",
				required, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			},
			/* [3] */
		"data size", "Return the size in bytes of an object", kAECoreSuite, kAEGetDataSize,
			cLongInteger,
			"the size of the object in bytes",
			replyRequired, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the object whose data size is to be returned",
			directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
			{	/* array OtherParams: 1 elements */
				/* [1] */
			"as", keyAERequestedType, cType,
				"the data type for which the size is calculated",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			},
			/* [4] */
		"delete", "Delete an element from an object", kAECoreSuite, kAEDelete,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the element to delete",
			directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [5] */
		"duplicate", "Duplicate objects(s)", kAECoreSuite, kAEClone,
			typeObjectSpecifier,
			"",
			replyRequired, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the object(s) to duplicate",
			directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 1 elements */
				/* [1] */
			"to", keyAEInsertHere, typeInsertionLoc,
				"the new location for the object(s)",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			},
			/* [6] */
		"exists", "Verify if an object exists", kAECoreSuite, kAEDoObjectsExist,
			typeBoolean,
			"true if it exists, false if not",
			replyRequired, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the object in question",
			directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [7] */
		"make", "Make a new element", kAECoreSuite, kAECreateElement,
			typeObjectSpecifier,
			"to the new object(s)",
			replyRequired, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 4 elements */
				/* [1] */
			"new", keyAEObjectClass, cType,
				"the class of the new element.",
				required, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
				/* [2] */
			"at", keyAEInsertHere, typeInsertionLoc,
				"the location at which to insert the element",
				required, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
				/* [3] */
			"with data", keyAEData, typeWildCard,
				"the initial data for the element",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
				/* [4] */
			"with properties", keyAEPropData, 'reco',
				"the initial values for the properties of the element",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			},
			/* [8] */
		"move", "Move object(s) to a new location", kAECoreSuite, kAEMove,
			typeObjectSpecifier,
			"to the object(s) after they have been moved",
			replyRequired, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the object(s) to move",
			directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 1 elements */
				/* [1] */
			"to", keyAEInsertHere, typeInsertionLoc,
				"the new location for the object(s)",
				required, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			},
			/* [9] */
		"open",
			"Open the specified object(s)", kCoreEventClass, kAEOpen, noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"list of objects to open",
			directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [10] */
		"print",
			"Print the specified object(s)", kCoreEventClass, kAEPrint, noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"list of objects to print",
			directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [11] */
		"quit",
			"Quit an application program", kCoreEventClass, kAEQuitApplication, noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, doesntChangeState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [12] */
		"save",
			"Save an object", kAECoreSuite, kAESave, noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the object to save",
			directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 3 elements */
				/* [1] */
			"in", keyAEFile, typeAlias,
				"the file in which to save the object",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
				/* [2] */
			"as", keyAEFileType, cType,
				"the file type of the document in which to save the data",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
				/* [3] */
			"makeCopy", keyAESaveCopy, cBoolean,
				"save a copy of the document without effecting the original",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			},
			/* [13] */
		"get",
			"Get the data for an object", kAECoreSuite, kAEGetData, typeWildCard,
			"the data from the object",
			replyRequired, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the object whose data is to be returned",
			directParamRequired, singleItem, notEnumerated, doesntChangeState, Reserved12,
			{	/* array OtherParams: 1 elements */
				/* [1] */
			"as", keyAERequestedType, cType,
				"the desired types for the data, in order of preference",
				optional, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			},
			/* [14] */
		"set",
			"Set an object's data", kAECoreSuite, kAESetData, noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"the object to change",
			directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 1 elements */
				/* [1] */
			"to", keyAEData, typeWildCard,
				"the new value",
				required, singleItem, notEnumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular
			}
		},
//----------------------------------------------------------------------------------------
// Classes
//----------------------------------------------------------------------------------------
		{	/* array Classes: 16 elements */
			/* [1] */
		"application", cApplication,
			"An application program",
			{	/* array Properties: 8 elements */
				/* [1] */
			"clipboard", pClipboard, typeWildCard,
				"the clipboard", reserved,
				listOfItems,
				notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"frontmost", pIsFrontProcess, typeBoolean,
				"Is this the frontmost application?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [3] */
			"name", pName, typeIntlText,
				"the name", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [4] */
			"selection", pUserSelection, cSelection,
				"the selection visible to the user", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [5] */
			"version", pVersion, cVersion,
				"the version number of the application", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [6] */
			"class", pClass, cType,
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 2 elements */
				/* [1] */
				cDocument,
				{	/* array KeyForms: 2 elements */
					/* [1] */
					formAbsolutePosition,
					/* [2] */
					formName
				},
				/* [2] */
				cWindow,
				{	/* array KeyForms: 2 elements */
					/* [1] */
					formAbsolutePosition,
					/* [2] */
					formName
				},
				/* [3] */
				cPalette,
				{	/* array KeyForms: 2 elements */
					/* [1] */
					formAbsolutePosition,
					/* [2] */
					formName
				}
			},
			/* [2] */
			"applications",
			cApplication,
			"Every application",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, cType,
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			},
			/* [3] */
		"character", cChar,
			"A character",
			{	/* array Properties: 9 elements */
				/* [1] */
			"color", pColor, cRGBColor,
				"the color", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"font", keyAEFont, cText,
				"the name of the font", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [3] */
			"size", pPointSize, cFixed,
				"the size in points", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [4] */
			"writing code", pScriptTag, cIntlWritingCode,
				"the script system and language", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [5] */
			"style", pTextStyles, cTextStyles,
				"the text style", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [6] */
			"uniform styles", pUniformStyles, cTextStyles,
				"the text style", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [7] */
			"class", pClass, cType,
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 2 elements */
				/* [1] */
				cChar,
				{	/* array KeyForms: 1 elements */
					/* [1] */
					formAbsolutePosition
				},
				/* [2] */
				cText,
				{	/* array KeyForms: 1 elements */
					/* [1] */
					formAbsolutePosition
				}
			},
			/* [4] */
		"characters", cChar,
			"Every character",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, cType,
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			},
			/* [5] */
		"document", cDocument,
			"A document",
			{	/* array Properties: 6 elements */
				/* [1] */
			"modified", pIsModified, cBoolean,
				"Has the document been modified since the last save?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"name", pName, cIntlText,
				"the name", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [3] */
			"selection", pSelection, cSelection,
				"the selection visible to the user", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [4] */
			"class", pClass, cType,
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 1 elements */
				/* [1] */
				cFile,
				{	/* array KeyForms: 2 elements */
					/* [1] */
					formAbsolutePosition,
					/* [2] */
					formName
				}
			},
			/* [6] */
		"documents", cDocument,
			"Every document",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, cType,
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			},
			/* [7] */
		"file", cFile,
			"A file",
			{	/* array Properties: 5 elements */
				/* [1] */
			"stationery", pIsStationeryPad, cBoolean,
				"Is the file a stationery file?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"name", pName, cIntlText,
				"the name", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [3] */
			"class", pClass, cType,
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 0 elements */
			},
			/* [8] */
		"files", cFile,
			"Every file",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, cType,
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			},
			/* [9] */
		"selection-object", cSelection,
			"the selection visible to the user",
			{	/* array Properties: 4 elements */
				/* [1] */
			"contents", pContents, cType,
				"the contents of the selection", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"class", pClass, cType,
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 0 elements */
			},
			/* [10] */
		"text", cText,
			"Text",
			{	/* array Properties: 10 elements */
				/* [1] */
			"", kAESpecialClassProperties, cType,
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural,
				/* [2] */
			"color", pColor, cRGBColor,
				"the color of the first character", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [3] */
			"font", pFont, cText,
				"the name of the font of the first character", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [4] */
			"size", pPointSize, cFixed,
				"the size in points of the first character", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [5] */
			"writing code", pScriptTag, cIntlWritingCode,
				"the script system and language of the first character", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [6] */
			"style", pTextStyles, cTextStyles,
				"the text style of the first character", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [7] */
			"uniform styles", pUniformStyles, cTextStyles,
				"the text styles that are uniform throughout the text", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [8] */
			"class", pClass, cType,
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 2 elements */
				/* [1] */
			cChar,
				{	/* array KeyForms: 1 elements */
					/* [1] */
					formAbsolutePosition
				},
				/* [2] */
			cText,
				{	/* array KeyForms: 1 elements */
					/* [1] */
					formAbsolutePosition
				}
			},
			/* [11] */
			"text style info",
			cTextStyles,
			"On and Off styles of text run",
			{	/* array Properties: 2 elements */
				/* [1] */
			"on styles", keyAEOnStyles, enumStyle,
				"the styles that are on for the text", reserved,
				listOfItems, enumerated,
				readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"off styles", keyAEOffStyles, enumStyle,
				"the styles that are off for the text", reserved,
				listOfItems, enumerated,
				readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 0 elements */
			},
			/* [12] */
			"text style infos",
			cTextStyles,
			"every text style info",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, cType,
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			},
			/* [13] */
		"window", cWindow,
			"A window",
			{	/* array Properties: 15 elements */
				/* [1] */
			"bounds", pBounds, cQDRectangle,
				"the boundary rectangle for the window", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"closeable", pHasCloseBox, cBoolean,
				"Does the window have a close box?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [3] */
			"titled", pHasTitleBar, cBoolean,
				"Does the window have a title bar?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [4] */
			"index", pIndex, cLongInteger,
				"the number of the window", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [5] */
			"modal", pIsModal, cBoolean,
				"Is the window modal?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [6] */
			"resizable", pIsResizable, cBoolean,
				"Is the window resizable?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [7] */
			"zoomable", pIsZoomable, cBoolean,
				"Is the window zoomable?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [8] */
			"zoomed", pIsZoomed, cBoolean,
				"Is the window zoomed?", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [9] */
			"name", pName, cIntlText,
				"the title of the window", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [10] */
			"selection", pSelection, cSelection,
				"the selection visible to the user", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [11] */
			"class", pClass, cType,
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 1 elements */
				/* [1] */
				cDocument,
				{	/* array KeyForms: 2 elements */
					/* [1] */
					formAbsolutePosition,
					/* [2] */
					formName
				}
			},
			/* [14] */
		"windows", cWindow,
			"Every window",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, cType,
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			},
			/* [15] */
		"palette", cPalette,
			"A floating palette",
			{	/* array Properties: 15 elements */
				/* [1] */
			"bounds", pBounds, cQDRectangle,
				"the boundary rectangle for the palette", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"closeable", pHasCloseBox, cBoolean,
				"Does the palette have a close box?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [3] */
			"titled", pHasTitleBar, cBoolean,
				"Does the palette have a title bar?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [4] */
			"index", pIndex, cLongInteger,
				"the number of the palette", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [5] */
			"floating", pIsFloating, cBoolean,
				"Does the palette float?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [6] */
			"resizable", pIsResizable, cBoolean,
				"Is the palette resizable?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [7] */
			"zoomable", pIsZoomable, cBoolean,
				"Is the palette zoomable?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [8] */
			"zoomed", pIsZoomed, cBoolean,
				"Is the palette zoomed?", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [9] */
			"name", pName, cIntlText,
				"the title of the palette", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [10] */
			"selection", pSelection, cSelection,
				"the selection visible to the user", reserved,
				singleItem, notEnumerated, readWrite, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [11] */
			"class", pClass, cType,
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 0 elements */
			},
			/* [16] */
		"palettes", cPalette,
			"Every palette",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, cType,
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			},
			/* [17] */
		"insertion point", cInsertionPoint,
			"An insertion location between two objects",
			{	/* array Properties: 3 elements */
			"class", pClass, cType,
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 0 elements */
			},
			/* [18] */
		"insertion points", cInsertionPoint,
			"Every insertion location",
			{	/* array Properties: 1 elements */
				/* [1] */
				"",
				kAESpecialClassProperties,
				cType,
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			}
		},
//----------------------------------------------------------------------------------------
// ComparisonOps
//----------------------------------------------------------------------------------------
		{	/* array ComparisonOps: 8 elements */
			"starts with", kAEBeginsWith, "Starts with",
			"contains", kAEContains, "Contains",
			"ends with", kAEEndsWith, "Ends with",
			"=", kAEEquals, "Equal",
			">", kAEGreaterThan, "Greater than",
			"", kAEGreaterThanEquals, "Greater than or equal to",
			"<", kAELessThan, "Less than",
			"", kAELessThanEquals, "Less than or equal to"
		},
//----------------------------------------------------------------------------------------
// Enumerations
//----------------------------------------------------------------------------------------
		{	/* array Enumerations: 2 elements */
			/* [1] */
			enumSaveOptions,
			{	/* array Enumerators: 3 elements */
				"yes", kAEYes, "Save objects now",
				"no", kAENo, "Do not save objects",
				"ask", kAEAsk, "Ask the user whether to save"
			},
			/* [2] */
			enumKeyForm,
			{	/* array Enumerators: 3 elements */
				"index", formAbsolutePosition, "keyform designating indexed access",
				"named", formName, "keyform designating named access",
				"ID", formUniqueID, "keyform designating access by unique identifer"
			}
		},

//========================================================================================
// Miscellaneous Standards
//========================================================================================

		/* [3] */
	"Miscellaneous Standards",
		"Miscellaneous standard events and classes",
		'misc',
		1,
		1,
//----------------------------------------------------------------------------------------
// Events
//----------------------------------------------------------------------------------------
		{	/* array Events: 12.1 elements */
			/* [11.1] */
		"revert", "Revert an object to its last saved state", kAEMiscStandards, kAERevert,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			typeObjectSpecifier,
			"list of object(s) to revert",
			directParamRequired, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [1] */
		"cut", "Cut an object to the clipboard", kAEMiscStandards, kAECut,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [2] */
		"copy", "Copy an object to the clipboard", kAEMiscStandards, kAECopy,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [3] */
		"paste", "Paste an object from the clipboard", kAEMiscStandards, kAEPaste,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [4] */
		"redo", "Reverse the action of the immediately preceeding undo", kAEMiscStandards, kAERedo,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
			/* [5] */
		"undo", "Undo the action of the previous event or user interaction", kAEMiscStandards, kAEUndo,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 0 elements */
			}
		},
//----------------------------------------------------------------------------------------
// Classes
//----------------------------------------------------------------------------------------
		{	/* array Classes: 4 elements */
			/* [1] */
			"menu",
			'cmnu',
			"A menu",
			{	/* array Properties: 5 elements */
				/* [1] */
			"class", 'pcls', 'type',
				"The class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"menu ID", 'mnid', 'shor',
				"the menu ID for the menu", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [5] */
			"name", 'pnam', 'itxt',
				"the name", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 1 elements */
				/* [1] */
				'cmen',
				{	/* array KeyForms: 2 elements */
					/* [1] */
					'indx',
					/* [2] */
					'name'
				}
			},
			/* [2] */
		"menus", 'cmnu',
			"Every menu",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, 'type',
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			},
			/* [3] */
		"menu item", 'cmen',
			"A menu item",
			{	/* array Properties: 6 elements */
				/* [1] */
			"class", 'pcls', 'type',
				"the class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [2] */
			"enabled", 'enbl', 'bool',
				"Is the menu item is enabled?", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [5] */
			"item number", 'itmn', 'shor',
				"the menu item number", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
				/* [6] */
			"name", 'pnam', 'itxt',
				"The name", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular
			},
			{	/* array Elements: 0 elements */
			},
			/* [4] */
		"menu items", 'cmen',
			"Every menu item",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, 'type',
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			}
		},
//----------------------------------------------------------------------------------------
// ComparisonOps
//----------------------------------------------------------------------------------------
		{	/* array ComparisonOps: 0 elements */
		},
//----------------------------------------------------------------------------------------
// Enumerations
//----------------------------------------------------------------------------------------
		{	/* array Enumerations: 1 element */
			/* [1] */
			enumQuality,
			{	/* array Enumerators: 3 elements */
				"draft", kAEFast, "image the graphic as quickly as possible",
				"regular", kAERegular, "image the graphic normally",
				"high", kAEHiQuality, "image the graphic at the highest quality possible"
			}
		},



//========================================================================================
// MacsBug Suite
//========================================================================================

		/* [4] */
	"MacsBug Suite",
		"MacsBug commands",
		kAEMacsBug,
		1,
		1,
//----------------------------------------------------------------------------------------
// Events
//----------------------------------------------------------------------------------------
		{	/* array Events: 1 elements */
			/* [1] */
		"check heap", "Check current heap for inconsistencies.", kAEMacsBug, kAEMacsBugHeapCheck,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 1 elements */
				/* [1] */
				"zone", keyAEMacsBugZone, enumMacsBugZones,
					"specifies which heap",
					optional, singleItem, enumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			},
		"heap zones", "List all known heap zones.", kAEMacsBug, kAEMacsBugHeapZones,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 0 elements */
			},
		"total heap", "Display a summary of the current heap (Heap Totals)", kAEMacsBug, kAEMacsBugHeapTotal,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 1 elements */
				/* [1] */
				"zone", keyAEMacsBugZone, enumMacsBugZones,
					"specifies which heap",
					optional, singleItem, enumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			},
		"display heap", "Display blocks in the current heap", kAEMacsBug, kAEMacsBugHeapDisplay,
			noReply,
			"",
			replyOptional, singleItem, notEnumerated, notTightBindingFunction, Reserved8, verbEvent, Reserved3,
			noParams,
			"",
			directParamOptional, singleItem, notEnumerated, changesState, Reserved12,
			{	/* array OtherParams: 1 elements */
				/* [1] */
				"zone", keyAEMacsBugZone, enumMacsBugZones,
					"specifies which heap",
					optional, singleItem, enumerated, Reserved9, prepositionParam, notFeminine, notMasculine, singular,
			},
		},
//----------------------------------------------------------------------------------------
// Classes
//----------------------------------------------------------------------------------------
		{	/* array Classes: 2 elements */
			/* [1] */
			"register",
			kAEMacsBugRegister,
			"A register",
			{	/* array Properties: 1 elements */
				/* [1] */
			"class", 'pcls', 'type',
				"The class", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, singular,
			},
			{	/* array Elements: 0 elements */
			},
			/* [2] */
			"registers", kAEMacsBugRegister,
			"Every register",
			{	/* array Properties: 1 elements */
				/* [1] */
			"", kAESpecialClassProperties, 'type',
				"", reserved,
				singleItem, notEnumerated, readOnly, Reserved8, noApostrophe, notFeminine, notMasculine, plural
			},
			{	/* array Elements: 0 elements */
			},
		},
//----------------------------------------------------------------------------------------
// ComparisonOps
//----------------------------------------------------------------------------------------
		{	/* array ComparisonOps: 0 elements */
		},
//----------------------------------------------------------------------------------------
// Enumerations
//----------------------------------------------------------------------------------------
		{	/* array Enumerations: 0 elements */
			/* [1] */
			enumMacsBugZones,
			{	/* array Enumerators: 3 elements */
				"system", kAEMacsBugZoneSystem, "System heap",
				"theZone", kAEMacsBugZoneApplication, "Application heap",
				"user", kAEMacsBugZoneUser, "User heap"
			},
		},


	}
};

